@@ -1,21 +1,25 @@
 package DateTime::Format::DBI;
-# $Id: DBI.pm 4060 2008-09-12 18:59:06Z cfaerber $
+# $Id: DBI.pm 4365 2009-12-10 18:11:51Z cfaerber $
 
 use strict;
 use vars qw ($VERSION);
+use warnings;
 
 use Carp;
 use DBI 1.21;
 
-$VERSION = '0.032';
-$VERSION = $VERSION + 0.0;
+$VERSION = '0.034';
+$VERSION = eval { $VERSION };
 
 our %db_to_parser = (
   # lowercase for case-insensitivity!
   'mysql'	=> 'DateTime::Format::MySQL',
   'pg'		=> 'DateTime::Format::Pg',
   'db2'		=> 'DateTime::Format::DB2',
-# 'oracle'	=> 'DateTime::Format::Oracle', # not tested
+  'mssql'	=> 'DateTime::Format::MSSQL',  # experimental
+  'oracle'	=> 'DateTime::Format::Oracle', # experimental
+  'sqlite'	=> 'DateTime::Format::SQLite', # experimental
+  'sybase'	=> 'DateTime::Format::Sybase', # experimental
 );
 
 sub new {
@@ -23,7 +27,7 @@ sub new {
   UNIVERSAL::isa($dbh,'DBI::db') || croak('Not a DBI handle.');
 
 # my $dbtype = $dbh->{Driver}->{Name};
-  my @dbtypes = DBI::_dbtype_names($dbh);
+  my @dbtypes = eval { DBI::_dbtype_names($dbh) };
   my $dbtype = shift @dbtypes;
 
   my $pclass = $db_to_parser{lc $dbtype};
@@ -40,7 +44,6 @@ sub new {
 
 DateTime::Format::DBI - Find a parser class for a database connection.
 
-
 =head1 SYNOPSIS
 
   use DBI;
@@ -59,19 +62,19 @@ DateTime::Format::DBI - Find a parser class for a database connection.
 This module finds a C<DateTime::Format::*> class that is suitable for the use with
 a given DBI connection (and C<DBD::*> driver).
 
-
-It currently supports the following drivers: 
+It currently supports the following format modules:
 L<IBM DB2 (DB2)|DateTime::Format::DB2>,
+L<Microsoft SQL (MSSQL)|DateTime::Format::MSSQL>, 
 L<MySQL|DateTime::Format::MySQL>, 
-# L<Oracle|DateTime::Format::Oracle>,
-L<PostgreSQL (Pg)|DateTime::Format::Pg>.
+L<Oracle|DateTime::Format::Oracle>,
+L<PostgreSQL (Pg)|DateTime::Format::Pg>,
+L<SQLite|DateTime::Format::SQLite>, and
+L<Sybase|DateTime::Format::Sybase>.
 
-B<WARNING:> This module provides a quick method to find the
-correct parser/formatter class. However, this is usually not
-enough for full database abstraction. You will usually have to
-care for differences not only in datetime syntax but also in the
-syntax and semantics of SQL datetime functions (and other SQL
-commands).
+B<NOTE:> This module provides a quick method to find the correct parser and
+formatter class. However, this is usually not sufficient for full database
+abstraction. You will also have to cater for differences in the syntax and
+semantics of SQL datetime functions (and other SQL commands).
 
 =head1 CLASS METHODS
 
@@ -80,17 +83,17 @@ commands).
 =item * new( $dbh )
 
 Creates a new C<DateTime::Format::*> instance the exact class of which depends
-on the driver used for the database connection referenced by $dbh. 
+on the driver used for the database connection referenced by C<$dbh>. 
 
 =back
 
 =head1 PARSER/FORMATTER INTERFACE
 
-C<DateTime::Format::DBI> is just a front-end factory that will return one of
-the format classes based on the nature of your $dbh.
+C<DateTime::Format::DBI> is just a front-end class factory that will return one
+of the format classes based on the nature of your C<$dbh>.
 
 For information on the interface of the returned parser object, please see the
-documentation for the class pertaining to your particular $dbh.
+documentation for the class pertaining to your particular C<$dbh>.
 
 In general, parser classes for databases will implement the following methods.
 For more information on the exact behaviour of these methods, see the
@@ -100,46 +103,39 @@ documentation of the parser class.
 
 =item * parse_datetime( $string )
 
-Given a string containing a date and/or time representation from
-the database used, this method will return a new C<DateTime>
-object.
+Given a string containing a date and/or time representation from the database
+used, this method will return a new C<DateTime> object.
 
 If given an improperly formatted string, this method may die.
 
 =item * format_datetime( $dt )
 
-Given a C<DateTime> object, this method returns a string
-appropriate as input for all or the most common date and date/time
-types of the database used. 
+Given a C<DateTime> object, this method returns a string appropriate as input
+for all or the most common date and date/time types of the database used. 
 
 =item * parse_duration( $string )
 
-Given a string containing a duration representation from the
-database used, this method will return a new C<DateTime::Duration>
-object.
+Given a string containing a duration representation from the database used,
+this method will return a new C<DateTime::Duration> object.
 
 If given an improperly formatted string, this method may die.
 
-Not all databases and format/formatter classes support durations;
-please use L<UNIVERSAL::has|UNIVERSAL/has> to check for the
-availability of this method.
+Not all databases and format/formatter classes support durations; please use
+L<UNIVERSAL::has|UNIVERSAL/has> to check for the availability of this method.
 
 =item * format_duration( $du )
 
-Given a C<DateTime::Duration> object, this method returns a string
-appropriate as input for the duration or interval type of the
-database used.
+Given a C<DateTime::Duration> object, this method returns a string appropriate
+as input for the duration or interval type of the database used.
 
-Not all databases and parser/formatter classes support durations;
-please use L<UNIVERSAL::has|UNIVERSAL/has> to check for the
-availability of this method.
+Not all databases and parser/formatter classes support durations; please use
+L<UNIVERSAL::has|UNIVERSAL/has> to check for the availability of this method.
 
 =back
 
-Parser/formatter classes may additionally define methods like
-parse_I<type> or format_I<type> (where I<type> is derived from the
-SQL type); please see the documentation of the individual format
-class for more information.
+Parser/formatter classes may additionally define methods like parse_I<type> or
+format_I<type> (where I<type> is derived from the SQL type); please see the
+documentation of the individual format class for more information.
 
 =head1 SUPPORT
 
@@ -148,11 +144,11 @@ list.  See http://lists.perl.org/ for more details.
 
 =head1 AUTHOR
 
-Claus A. Färber <perl@cfaerber.name>
+Claus FE<auml>rber <CFAERBER@cpan.org>
 
-=head1 COPYRIGHT
+=head1 LICENSE
 
-Copyright © 2003-2008 Claus A. Färber.  All rights reserved.  
+Copyright 2003-2010 Claus FE<auml>rber.  All rights reserved.  
 
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
